@@ -2,33 +2,14 @@ use strict;
 use warnings;
 
 package App::Cmd::Subdispatch::DashedStyle;
+BEGIN {
+  $App::Cmd::Subdispatch::DashedStyle::VERSION = '0.308';
+}
 use App::Cmd::Subdispatch;
 BEGIN { our @ISA = 'App::Cmd::Subdispatch' };
 
-=head1 NAME
+# ABSTRACT: "app cmd --subcmd" style subdispatching
 
-App::Cmd::Subdispatch::DashedStyle - "app cmd --subcmd" style subdispatching
-
-=head1 VERSION
-
-version 0.306
-
-=cut
-
-our $VERSION = '0.306';
-
-=head1 METHODS
-
-=head2 get_command
-
-  my ($subcommand, $opt, $args) = $subdispatch->get_command(@args)
-
-A version of get_command that chooses commands as options in the following
-style:
-
-  mytool mycommand --mysubcommand
-
-=cut
 
 sub get_command {
 	my ($self, @args) = @_;
@@ -44,21 +25,12 @@ sub get_command {
   }
 }
 
-=for Pod::Coverage prepare_default_command
-
-=cut
 
 sub prepare_default_command {
   my ( $self, $opt, @args ) = @_;
   $self->_prepare_command( "help" );
 }
 
-=head2 opt_spec
-
-A version of C<opt_spec> that calculates the getopt specification from the
-subcommands.
-
-=cut
 
 sub opt_spec {
 	my ($self, $app) = @_;
@@ -82,3 +54,46 @@ sub opt_spec {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+App::Cmd::Subdispatch::DashedStyle - "app cmd --subcmd" style subdispatching
+
+=head1 VERSION
+
+version 0.308
+
+=head1 METHODS
+
+=head2 get_command
+
+  my ($subcommand, $opt, $args) = $subdispatch->get_command(@args)
+
+A version of get_command that chooses commands as options in the following
+style:
+
+  mytool mycommand --mysubcommand
+
+=head2 opt_spec
+
+A version of C<opt_spec> that calculates the getopt specification from the
+subcommands.
+
+=for Pod::Coverage prepare_default_command
+
+=head1 AUTHOR
+
+Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
